#
# spec file for package nss_ldap (Version 259)
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           nss_ldap
BuildRequires:  db-devel krb5-devel openldap2-devel
License:        LGPL v2.1 or later
Group:          Productivity/Networking/LDAP/Clients
PreReq:         /usr/bin/grep /usr/bin/sed /bin/mktemp
AutoReqProv:    on
Version:        259
Release:        4.11.18
Summary:        NSS LDAP Module
Url:            http://www.padl.com/OSS/nss_ldap.html
Source:         nss_ldap-%{version}.tar.bz2
Source1:        README.SuSE
Patch:          nss_ldap.dif
Patch1:         group-utf8.dif
Patch2:         nss_ldap-defport-ssl-uri.dif
Patch3:         nss_ldap-oneshot-initgroups.dif
Patch4:         nss_ldap-reconnect-after-do_result-failure.dif
Patch5:         nss_ldap-ldapconn-leak-bug418.dif
Patch6:         nss_ldap-getent-retry.dif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Nss_ldap is a glibc NSS module that allows X.500 and LDAP directory
servers to be used as a primary source of aliases, ethers, groups,
hosts, networks, protocol, users, RPCs, services, and shadow passwords
(instead of or in addition to using flat files or NIS).



Authors:
--------
    Luke Howard <lukeh@padl.com>

%prep
%setup -q
%patch -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
cp -v %{S:1} .

%build
%{?suse_update_config:%{suse_update_config -f}}
autoreconf
CFLAGS="$RPM_OPT_FLAGS" \
CPPFLAGS="-I/usr/include/sasl -DINET6" \
./configure --prefix=/usr \
            --mandir=%{_mandir} \
	    --enable-rfc2307bis \
	    --enable-schema-mapping \
	    --enable-xad \
	    --enable-paged-results \
            --enable-configurable-krb5-ccname-gssapi \
	    --libdir=%{_libdir} \
	    --sysconfdir=/etc \
	    --x-libraries=/usr/X11R6/%{_lib}
make

%install
rm -fr $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/%{_lib}
mkdir -p $RPM_BUILD_ROOT%{_libdir}
install -m 755 nss_ldap.so $RPM_BUILD_ROOT/%{_lib}/libnss_ldap.so.2
ln -s ../../%{_lib}/libnss_ldap.so.2 $RPM_BUILD_ROOT%{_libdir}/libnss_ldap.so
make DESTDIR=$RPM_BUILD_ROOT install-man

%clean
rm -fr $RPM_BUILD_ROOT

%post
/sbin/ldconfig
if [ ${1:-0} -gt 1 ] ; then
    if ! /usr/bin/grep -q ^bind_policy /etc/ldap.conf; then
        if grep -q -e ^#[[:space:]]\*bind_policy /etc/ldap.conf; then
            LDAP_ORIG=`mktemp /tmp/ldap.conf.XXXXXXXXXX`
            cp /etc/ldap.conf $LDAP_ORIG
            sed -e 's;^#[[:space:]]*bind_policy.*$;bind_policy soft;' \
                $LDAP_ORIG > /etc/ldap.conf
            rm $LDAP_ORIG
        else
            echo -e "\n"\
"#Don't try forever if the LDAP server is not reacheable\n"\
"bind_policy soft" >> /etc/ldap.conf
        fi
    fi
fi

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ANNOUNCE AUTHORS COPYING ChangeLog NEWS README README.SuSE nsswitch.ldap ldap.conf doc/README.paged
/%{_lib}/libnss_ldap.so.2
%{_libdir}/libnss_ldap.so
%doc %{_mandir}/man5/nss_ldap.5*

%changelog
* Wed Jan 12 2011 rhafer@suse.de
- A memory leak in nss_ldap could lead to processes (e.g. nscd)
  growing extremely large (bnc#659100, PADL-Bug#418)
- nss_ldap didn't try to reconnect properly when the LDAP
  connection was lost between two getXXent() calls
  (bnc#662752, PADL-Bug#215)
* Thu Aug 19 2010 rhafer@novell.com
- Close LDAP connections which previously returned an error or
  timeout, to force a reconnect (bnc#621317, PADL-Bug#392).
  Otherwise nss_ldap might try to use that connection again and
  run into the same timeout multiple times, which can cause huge
  delays and lead to trouble with e.g. nscd.
- Plug some file descriptor leaks in the config parsing code
  (bnc#621317, PADL-Bug#410)
* Fri Jul 23 2010 rhafer@novell.com
- Avoid closing LDAP connection to early in initgroups() when
  "oneshot" mode is used (bnc#604768)
* Mon May 18 2009 rhafer@novell.com
- Only set default port when "port" directive is present in
  /etc/ldap.conf or when "ssl on" is set. (bnc#440139)
- Apply "tls_*" options when "ldaps" URI are used (bnc#440139)
* Thu Nov  8 2007 rhafer@suse.de
- Update to nss_ldap-259 (Fate #302643). Most important changes:
  * Consolidates fixes for Bugs #335117, #288910, #310556, #248594,
    [#214348] and #215911)
  * fix for PADL-Bug#338: nss_ldap constructs LDAP URIs incorrectly
  * patch to from Ralf Haferkamp <rhafer@suse.de>: block SIGPIPE
    in atfork handler
  * patch from Tomas Janousek <tjanouse@redhat.com> to check for
    pthread_once(); (Bug #339031)
    __pthread_once does not imply __pthread_atfork being non-NULL
  * fix for PADL-Bug#315: memory corruption/crash in initgroups parsing
  * fix for PADL-Bug#304: fd leak in do_close_no_unbind
  * fix for PADL-Bug#292: array bounds check in ldap-network.c
  * fix for PADL-Bug#296: fix stack buffer optimization
* Mon Oct 22 2007 rhafer@suse.de
- nss_ldap crashes when a timeout occurs during the START_TLS
  operation (Bug #335117)
- ldap_msg_free() could be called multiple times for the same
  data (Bug #288910)
- nss_ldap potentially closes an LDAP connection that is still
  in use by another thread (Bug #310556)
* Thu Mar  1 2007 rhafer@suse.de
- nss_ldap could crash when no host or uri is configured in
  /etc/ldap.conf or DNS (Bug #248594)
* Mon Feb 12 2007 rhafer@suse.de
- Fixed a possible deadlock in _nss_ldap_initgroups_dyn(), which
  caused multi-thread applications to hang.
  (Bugzilla #214348, PADL-Bug #255)
* Mon Jan 15 2007 rhafer@suse.de
- Fixed crasher, when parsing nested groups of a certain size
  (Bugzilla: #215911)
* Mon Mar 13 2006 rhafer@suse.de
- Don't use static buffer for groups without members
  (Bugzilla: #157066)
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 26 2006 rhafer@suse.de
- retry at least one time if "bind_policy soft"
- better workaround for __pthread_once and pthread_atfork hacks
* Wed Jan 25 2006 rhafer@suse.de
- Update to nss_ldap-246 (Bugzilla: #145170)
* Thu Jan 19 2006 rhafer@suse.de
- add "bind_policy soft" to /etc/ldap.conf during update
  if no "bind_policy" is set explicitly (Bugzilla: #139578)
* Fri Jan 13 2006 rhafer@suse.de
- Fixed paged results. http://bugzilla.padl.com/show_bug.cgi?id=245
* Wed Jan 11 2006 rhafer@suse.de
- Update to nss_ldap-245
* Tue Jan 10 2006 rhafer@suse.de
- use pthread_atfork() instead of glibc-internal __pthread_once
- neededforbuild cleanup
* Thu Dec 22 2005 rhafer@suse.de
- Update to nss_ldap-244
- Fixed man-page it's "bind_policy" not "reconnect_policy"
* Wed Oct 12 2005 rhafer@suse.de
- Update to nss_ldap-243
* Tue Mar 29 2005 rhafer@suse.de
- Update to nss_ldap-238
* Mon Feb 21 2005 rhafer@suse.de
- Update to nss_ldap-234 (contains a better fix for Bug #50702)
* Mon Feb 14 2005 rhafer@suse.de
- Update to nss_ldap-233
- connect_on_init.dif: fixes Bug #50702
* Fri Jan 28 2005 rhafer@suse.de
- Update to nss_ldap-232
- Fixed path in README.SuSE
* Tue Jan 18 2005 rhafer@suse.de
- Update to nss_ldap 229
- added kerberos-devel-packages to neededforbuild and turned on
  configurable Kerberos V credentials cache name
* Thu Oct 14 2004 rhafer@suse.de
- Update to nss_ldap 226
- fixed README.SuSE
* Thu Feb 19 2004 kukuk@suse.de
- Increase the buffer for struct sockaddr to hold all data.
* Wed Feb 18 2004 kukuk@suse.de
- Add patch to fix seg.fault from Ralf Haferkamp
* Sat Feb 14 2004 kukuk@suse.de
- Update to nss_ldap 215
- Fix handling of UTF-8 group names [Bug #34549]
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig and %%defattr
* Tue Sep  2 2003 sbrabec@suse.cz
- Turned on schema mapping, XAD support and paged results.
- Packaged more docs.
* Mon Jul 14 2003 sbrabec@suse.cz
- Changed path to ldap.conf to /etc (bug #27528).
* Mon Jun  9 2003 sbrabec@suse.cz
- Updated to version 207.
* Sat Feb 15 2003 kukuk@suse.de
- Update to 203.7. Includes netgroup support.
* Fri Feb 14 2003 kukuk@suse.de
- Fix seg.fault on x86-64 in gethost* functions
- Implement IPv6 support for gethost* functions
* Thu Feb 13 2003 kukuk@suse.de
- Enable IPv6 support (else we will leak file descriptors with IPv6
  addresses).
* Tue Nov  5 2002 sbrabec@suse.cz
- Update to version 203.
* Tue Oct 29 2002 sbrabec@suse.cz
- Update to version 202.
- Don't own /etc/openldap, required openldap2-client creates it.
* Thu Aug 29 2002 tcrhak@suse.cz
- fixed sigprocmask bug (bug #18236)
* Mon Aug 26 2002 rhafer@suse.de
- LDAP_FILT_MAXSIZ isn't defined in libldap anymore
* Tue Aug 13 2002 kukuk@suse.de
- Update to version 199 (glibc alias enumeration functions, DNS
  response parser)
* Sat Jul 27 2002 kukuk@suse.de
- Update to version 198 (fixes a potential buffer overflow in the
  DNS SRV code)
* Tue Jul 16 2002 kukuk@suse.de
- Update to version 197 (lot of "buffer to small" bug fixes)
* Sat Apr 27 2002 kukuk@suse.de
- Update to 187 (minor bug fixes)
* Mon Feb  4 2002 tcrhak@suse.cz
- update to 183
- used %%{_lib} and %%{_lidir} macros
* Fri Nov 23 2001 tcrhak@suse.cz
- update to version 174
* Tue Aug  7 2001 cihlar@suse.cz
- update to version 167
* Sat May 12 2001 schwab@suse.de
- Fix missing declarations.
- Add %%suse_update_config.
* Thu Apr 19 2001 kukuk@suse.de
- Do not enable ids-uid, it is broken
* Wed Apr 18 2001 pblaha@suse.cz
- back to /etc/openldap/ldap.conf
- update on version 150
- add URL
* Wed Mar 21 2001 ro@suse.de
- fixed neededforbuild again
* Fri Mar 16 2001 pblaha@suse.cz
- update on version 149
- add build root
* Thu Mar 15 2001 ro@suse.de
- fixed neededforbuild for openldap
* Wed Jan 31 2001 choeger@suse.de
- link against ldaplib2
* Mon Dec 11 2000 kukuk@suse.de
- Update to 123
* Sat Nov  4 2000 kukuk@suse.de
- Use ldaplib
* Thu Jun  1 2000 kukuk@suse.de
- Update to 110
* Mon Apr 10 2000 kukuk@suse.de
- Fix typo in path to config file
* Tue Feb 15 2000 kukuk@suse.de
- Update to version 105
* Tue Oct 12 1999 kukuk@suse.de
- Update to 87
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Aug  9 1999 kukuk@suse.de
- Update to 85
* Mon Jul 12 1999 kukuk@suse.de
- Update to 81
- Add ldap.conf and README.SuSE to documentation
* Fri Jun 25 1999 kukuk@suse.de
- Update to 2.77
* Wed Jun  9 1999 kukuk@suse.de
- Update to 2.69
* Fri May  7 1999 kukuk@suse.de
- Initial version of nss_ldap 2.64
